@@ -7,26 +7,25 @@ import shutil
 import subprocess
 import sys
 import traceback
-from multiprocessing.pool import ThreadPool
 from dataclasses import dataclass
 from enum import Enum
 from functools import partial
+from multiprocessing.pool import ThreadPool
 from pathlib import Path
 
+import httpx
 import pandas as pd
-import requests
 import tqdm
 from tenacity import (
     retry,
     retry_if_exception_type,
-    wait_exponential,
     stop_after_attempt,
+    wait_exponential,
 )
 from tqdm.contrib.logging import logging_redirect_tqdm
 
 from gpas import data_dir, validation
 
-
 FORMATS = Enum("Formats", dict(table="table", csv="csv", json="json"))
 DEFAULT_FORMAT = FORMATS.table
 ENVIRONMENTS = Enum("Environment", dict(dev="dev", staging="staging", prod="prod"))
@@ -47,6 +46,10 @@ class SubmissionError(Exception):
     pass
 
 
+class SubprocessError(Exception):
+    pass
+
+
 ENDPOINTS = {
     "dev": {
         "HOST": "https://portal.dev.gpas.ox.ac.uk/",
@@ -64,9 +67,9 @@ ENDPOINTS = {
     },
     "staging": {
         "HOST": "https://portal.staging.gpas.ox.ac.uk/",
-        "API_PATH": "ords/gpasuat/gpas_pub/gpasapi/",
-        "ORDS_PATH": "ords/gpasuat/grep/electron/",
-        "DASHBOARD_PATH": "ords/gpas/r/gpas-portal/lineages-voc/",
+        "API_PATH": "ords/gpas_pub/gpasapi/",
+        "ORDS_PATH": "ords/grep/electron/",
+        "DASHBOARD_PATH": "",
         "NAME": "STAGE",
     },
 }
@@ -145,9 +148,16 @@ def run_logged(
         print_progress_message_json(
             action=command.action, status="started", sample=command.name
         )
-    process = subprocess.run(
-        command.cmd, shell=True, check=True, text=True, capture_output=True
+    process = subprocess.run(command.cmd, shell=True, text=True, capture_output=True)
+    logging.debug(
+        f"Executed command {process.args} {process.stderr=}"
+        f" {process.stdout=} {process.returncode=}"
     )
+    if process.returncode != 0:
+        raise SubprocessError(
+            f"Failed to execute command {process.args} {process.stderr=}"
+            f" {process.stdout=} {process.returncode=}"
+        )
     if json_messages:
         print_progress_message_json(
             action=command.action, status="finished", sample=command.name
@@ -161,7 +171,7 @@ def run_parallel_logged(
     participle: str = "processing",
     json_messages: bool = False,
 ) -> dict[str, subprocess.CompletedProcess]:
-    processes = 1 if sys.platform == "win32" else processes
+    processes = 1 if platform.system() == "Windows" else processes
     if json_messages:
         print_progress_message_json(action=commands[0].action, status="started")
     if processes == 1:
@@ -281,7 +291,7 @@ def get_reference_path(organism):
 
 
 @retry(
-    retry=retry_if_exception_type(requests.exceptions.ConnectionError),
+    retry=retry_if_exception_type(httpx.TransportError),
     wait=wait_exponential(multiplier=1, min=1, max=5),
     stop=stop_after_attempt(5),
 )
@@ -291,11 +301,11 @@ def upload_sample(upload: SampleUpload, headers: dict, json_messages: bool) -> N
             action="upload", status="started", sample=upload.name
         )
     with open(upload.path1, "rb") as fh:
-        r = requests.put(url=upload.url1, data=fh, headers=headers)
+        r = httpx.put(url=upload.url1, data=fh, headers=headers)
         r.raise_for_status()
     if upload.path2 and upload.url2:
         with open(upload.path2, "rb") as fh:
-            r = requests.put(url=upload.url2, data=fh, headers=headers)
+            r = httpx.put(url=upload.url2, data=fh, headers=headers)
             r.raise_for_status()
     logging.debug(f"Uploaded sample {upload.name}")
     if json_messages:
